package App::StaticImageGallery::Style::Source::FromDir;
BEGIN {
  $App::StaticImageGallery::Style::Source::FromDir::VERSION = '0.002';
}
use parent 'App::StaticImageGallery::Base::Source';

1;
__END__

=head1 NAME

App::StaticImageGallery::Base::Style

=head1 VERSION

version 0.002

=head1 DESCRIPTION

=head1 SYNOPSIS

=head1 METHODS

=head1 AUTHOR

See L<App::StaticImageGallery/AUTHOR> and L<App::StaticImageGallery/CONTRIBUTORS>.

=cut